@@ -3,12 +3,16 @@
 
 """Module for environments for flask."""
 
-from .azure_nb_env import AzureNBEnvironment
+from .azure_nb_environment import AzureNBEnvironment
+from .credentialed_vm_environment import CredentialedVMEnvironment
 from .databricks_environment import DatabricksEnvironment
 from .local_ipython_environment import LocalIPythonEnvironment
+from .public_vm_environment import PublicVMEnvironment
 
 __all__ = [
     'AzureNBEnvironment',
+    'CredentialedVMEnvironment',
     'DatabricksEnvironment',
-    'LocalIPythonEnvironment'
+    'LocalIPythonEnvironment',
+    'PublicVMEnvironment'
 ]
