@@ -29,11 +29,6 @@ class PublicVMEnvironment(BaseEnvironment):
                 self.successfully_detected = True
                 self.base_url = f"http://{service.ip}:{service.port}"
 
-    def display(self, html):
-        """Display the passed HTML using IPython."""
-        from IPython.display import HTML, display
-        display(HTML(html))
-
     def select(self, service):
         service.with_credentials = False
         service.cors = CORS(service.app)
